%% CPROMIN: Consensus Promin Rotation
%
% ARGUMENTS   : A    -> supermatrix with different sets of columns.
%               p    -> number of sets.
%               m    -> vector with column orders of A(k) .
%               conv -> convergence criterion.
%               nrs  -> number of random starts.
%
% RETURN VALUE: T   -> supermatrix with T(1)...T(p).
%               PHI -> Inter-factor correlation matrix
%               Po  -> Consensus pattern matrix
%               H   -> Consensus target matrix
%               fr  -> function value.
%               ir  -> number of iterations.
%
% DEPENDENCIES: ed.m
%               gpanew.m
%               nor.m
%               nrm.m
%               part.m
%               promin.m
%               ssq.m
%               tarrotob.m
%               urbmaj.m
%               wvarim.m
%

function [T,PHI,Po,H,fr,ir] = cpromin(A,p,m,conv,nrs);

   n = size(A);
   
   [Tr,fr,ir]=gpanew(A,p,m,conv,nrs);  

   SA = zeros(n(1),m(1));
   for k=1:p,
       SA= SA + part(A,k,m)*Tr(:,(k-1)*m+1:k*m);
   end;
      
   SA = SA ./ p;   

   [To,Uo] = promin(SA,conv,nrs);

   PHI = Uo'*Uo;
   Po = SA*To;

   T = [];
   for k=1:p,
       SA = part(A,k,m);
       To = (SA'*SA)^(-1) * SA' * Po;
       T = [T To];
   end;
