%% EAP_GRAD_OBLI: EAP POINT ESTIMATES IN THE r-FACTOR UVA MODEL WITH STANDARD ERRORS AND RELIABILITY ESTIMATES
%
% ARGUMENTS   : X     ->  VECTOR OF ITEM SCORES (SCORED 1 TO k)
%               LAM   ->  LOADING FACTOR PATTERN (items x dimension factors)
%               PHI   ->  INTER-FACTOR CORRELATION MATRIX (dimension factors x factors)
%               THRES ->  TRHRESHOLD MATRIX (dimension thresholds x items with a final row of zeros)
%               sigj  ->  VECTOR OF ITEM RESIDUAL STANDARD DEVIATIONS
%               grid  ->  MATRIX OF QUADRATURE POINTS 
%         index_nodos ->  INDEX MATRIX FOR nodos
%
% RETURN VALUE: TH    -> factor scores.
%               SE    -> standard errors
%               RELI  -> reliability of factor scores
%
% DEPENDENCIES: ordnormulti.m
%               pconmul.m
%

function [TH,SE,RELI] = eap_grad_obli(X,LAM,PHI,THRES,sigj,grid, index_nodos);

[n,m] = size(X);

if  (n>m), ni=n; 
else       ni=m; end;

[m,r] = size(LAM);
[nnod,tmp]=size(grid);
[hnod,r] =size(index_nodos);

d=grid(2,1)-grid(1,1);

L1 = zeros(nnod^r,1);

nume_th=zeros(r,1);
nume_se=zeros(r,1);

TH = zeros(r,1);
SE = zeros(r,1);
RELI = zeros(r,1);

deno =0;
p = zeros (ni,1);

for h=1:hnod,
    
     %vector de theta a evaluar
     zi=zeros(r,1);
     for i=1:r,
         zi(i) = grid(index_nodos(h,i));
     end;
     
     L1(h,1) = 0;
     for j=1:ni,

         p1=0;
         %%%  WARNING: Binary data giving error when 0 (THRES(X(j)-1,j)->
         %%%  THRES(-1,j)-> error indexing
         if ((X(j)-1) ~= 0),
            p1 =  (X(j)-1)*log(pconmul(zi,LAM(j,:),THRES(X(j)-1,j),sigj(j)));
         end;
         p2 = 0;
         if (THRES(X(j)  ,j) ~= 0),
            p2 =  X(j)*log(1-pconmul(zi,LAM(j,:),THRES(X(j),j),sigj(j)));
         end;
            p(j) = p2 + p1;
         
         % crea la funcion de verosimilitud
         L1(h,1) = L1(h,1) + p(j);
         
     end;

     % calcula la densidad bivariada en cada punto de la rejilla
     % las medias y varianzas de theta son 0 y 1
     term1=ordnormulti(zi,PHI); 
     term2=term1*d*d;
       
     % calcula las estimaciones EAP y los PSDs
     pp = exp(L1(h,1))*term2;

     deno  = deno  + pp;
     for i=1:r,
         nume_th(i)=nume_th(i) + pp*grid(index_nodos(h,i),1);
         nume_se(i)=nume_se(i) + pp*grid(index_nodos(h,i),1)*grid(index_nodos(h,i),1);
     end;

end;

VAR_E=zeros(r,1);
VAR_EE=zeros(r,1);
Se2 = zeros(r,1);
IPHI=PHI^(-1);
for i=1:r,
  TH(i,1) = nume_th(i)/ deno;
%   SE(i,1) = sqrt(nume_se(i)/deno - (TH(i,1)*TH(i,1)) );
%   RELI(i,1) = 1-(nume_se(i)/deno - (TH(i,1)*TH(i,1)) );
  VAR_E(i,1) = nume_se(i)/deno - (TH(i,1)*TH(i,1));
  VAR_EE(i,1) = 1 - VAR_E(i,1);
  Se2(i,1) = VAR_E(i,1) /( 1.0 - IPHI(i,i)*VAR_E(i,1));
  SE(i,1) = sqrt(Se2(i,1));
  RELI(i,1) = (VAR_EE(i,1) - Se2(i,1))/VAR_EE(i,1);
end;  
  
return;

