%% REAP_GRAD_OBLI : EAP estimation for a r-dimensional UVA factor model. Joint estimation for all respondents
% see "eap_grad_obli.m" for details              
%               
% ARGUMENTS   : X     ->  MATRIX OF ITEM SCORES (SCORED 1 TO 5)
%               LAM   ->  LOADING FACTOR PATTERN (dimension factors x items)
%               PHI   ->  INTER-FACTOR CORRELATION MATRIX (dimension factors x factors)
%               THRES ->  TRHRESHOLD MATRIX (dimension thresholds x items with a final row of zeros)
%               sigj  ->  VECTOR OF ITEM RESIDUAL STANDARD DEVIATIONS            
%               
% 28/06/2018  : n_nodes -> number of nodes to be used between 7 and 40
%
% RETURN VALUE: th    -> factor scores.
%               th_li -> factor scores inferior limit.
%               th_ls -> factor scores upper limit.
%               se    -> standard errors
%               reli  -> reliability of factor scores
%
% DEPENDENCIES: Nseriesk.m
%               Time2String.m
%               eap_grad_obli.m
%               ordnormulti.m
%               pconmul.m
%

function [th,th_li,th_ls,se,reli] = reap_grad_obli(X, LAM, PHI, THRES, sigj,n_nodes,disp);

[m,r]=size(LAM);

%create grid
grid= [-4:(8/n_nodes):4]';

index_nodos = Nseriesk(n_nodes,r);

% [m,r]=size(LAM);
% 
% %to create grid
% switch(r)
% case {1, 2}
%     %21 nodos
%     grid = [-4:(8/20):4]';
% case 3
%     %17 nodos
%     grid = [-4:(8/16):4]';
% case 4
%     %11 nodos
%     grid = [-4:(8/10):4]';
% otherwise
%     %7 nodos
%     grid = [-4:(8/6):4]';
% end;
% 
% [ni,tmp]=size(grid);
% index_nodos = Nseriesk(ni,r);

%%%%%%%%%%%%%%%%%%%%%%
[n,m] = size(X);

if disp == 1,
   tstart = tic;
   buff_bar{1}='EAP latent traits estimates';
%    switch type
%        case 1
%            buff_bar{1}='EAP latent traits estimates for SD factor';
%        case 2
%            buff_bar{1}='EAP latent traits estimates for AC factor';
%        case 3
%            buff_bar{1}='EAP latent traits estimates for content factors';
%    end;
   buff_bar{2}=' '; tmp3 = 0; bar1 = waitbar(tmp3,buff_bar);
end;    

%FAC = [];
th=[];
se=[];
reli=[];
for i=1:n,

    [i X(i,:)];
    if min(X)==0
        X=X+1;
    end
    [th_i,se_i,reli_i] =  eap_grad_obli(X(i,:),LAM, PHI, THRES, sigj, grid, index_nodos);
    th = [th; th_i'];
    se = [se; se_i'];
    reli = [reli; reli_i'];
%    FAC = [FAC; th',se',reli'];
    if (disp >0),
        compT = toc(tstart);
        compT = compT*(n-i)/i;
        buff_bar{2} = ['(Remaining time = ' Time2String( compT ) ')'];
%         s_tmp=['EAP latent traits estimates (Remaining time = ' Time2String( compT ) ')'];
        waitbar(i/n,bar1,buff_bar);
     end;
end;

 z90= 1.64485362695147;
 
% 90% approximate confidence interval
  th_li= zeros(n,r);
  th_ls= zeros(n,r);
  for i=1:n,
	  for j=1:r
		  th_li(i,j) = th(i,j) - z90*se(i,j);
		  th_ls(i,j) = th(i,j) + z90*se(i,j);
      end;
  end;

  if disp == 1,close(bar1);end;
  
  return;
  