%% TETRA2005 : Algorithm to compute the tetrachoric correlation (R) from the frequencies of a 2*2 table (f11,f12,f21 and f22) BONETT AND PRICE 2005
%
%               V2
%                0    1
%        V1 0    f11    f12
%           1    f21    f22
%

function [r,IC]=tetra2005(f11,f12,f21,f22)
PI = 3.14159265358979;

f11_05 = (f11 + 0.5);
f22_05 = (f22 + 0.5);
f12_05 = (f12 + 0.5);
f21_05 = (f21 + 0.5);

n = f11_05 + f12_05 + f21_05 + f22_05;
p11 = f11_05 / n;
p22 = f22_05 / n;
p12 = f12_05 / n;
p21 = f21_05 / n;

p1m = p11 + p12;
p2m = 1.0 - p1m;
pm1 = p11 + p21;
pm2 = 1.0 - pm1;
pmin = min([p1m; pm1; p2m; pm2]);

ec = ( 1- abs(p1m - pm1)/5 - ((0.5 - pmin)*(0.5 - pmin)) )/2;
eo = f11_05*f22_05/(f12_05 * f21_05);

 r = cos(PI/(1 + eo^ec ));
IC=0;

     return;
