%% THRESHOLDS: Computes thresholds for Polychoric Matrix Calculation and EAP factor scores
%
% ARGUMENTS   : X    -> Binary Matrix  (N x m)
%               Xmin -> Vector containing the minimum value of the variables (m x 1)
%               Xmax -> Vector containing the maximum value of the variables (m x 1)
%
%
% RETURN VALUE: THRES -> Variable's Thresholds
%
% DEPENDENCIES: ppnd.m
%
% LAST UPDATED : 06/11/2017
%                Urbano Lorenzo-Seva
%

function THRES=thresholds(X,Xmin,Xmax);
   
if nargin<3, 
     fprintf ( 1, 'thresholds error\n' );
     fprintf ( 1, '' );
     help thresholds
     fprintf ( 1, '' );
     return
end;

[N,m] = size(X);
Ki = (Xmax - Xmin + 1);
Kmax= max(Ki);

THRES=zeros(m,max(Ki')-1);

FR = zeros(m,Kmax);
for i=1:m,
    Xmi = min(X(:,i));
    for k=1:N,
     jth=1;
     for j=1:Kmax,
        if X(k,i) == (Xmi-1+j), jth = j; end;
     end;
     FR(i,jth)= FR(i,jth) + 1;
    end;
    FR(i,:)=FR(i,:)/N;
    for k=1:Kmax-1,
       tmp1= sum(FR(i,1:k)');
       THRES(i,k)=ppnd(tmp1);
    end;
end;

return;
